import { useRef, useState } from "react";
import Editor from "./editor";
import { actionSnippetAdd } from "../actions/actionSnippetAdd";
import { connect } from "react-redux";
import { Redirect } from "react-router";
import { useEffect } from "react";

const SnippetHome = ({ onSave }) => {
  const [files, setFiles] = useState([
    { type: "html", text: '<h1 id="codePen">Hello on ver2ex CodePen</h1>' , name:'index.html' },
    { type: "css", text: "#codePen{\n    color: #5F9EA0;\n}" , name:'style.css'},
    {
      type: "javascript",
      text: "let btn = document.createElement('button')\nlet btn1 = document.createElement('button')\nbtn.innerHTML = 'Switch to blue'\nbtn.style.color = '#5F9EA0'\nbtn.style.marginRight = '5px'\nbtn1.innerHTML = 'Switch to orange'\nbtn1.style.color = '#FF7F50'\ndocument.body.append(btn)\ndocument.body.append(btn1)\nbtn.onclick = () => {\n    document.getElementById('codePen').style.color = '#5F9EA0'\n}\nbtn1.onclick = () => {\n    document.getElementById('codePen').style.color = '#FF7F50'\n}",
      name:'main.js'
    },
  ]);
  const [name, setName] = useState("");
  const [title, setTitle] = useState("");
  const [description, setDescription] = useState("");
  const [srcDoc, setSrcDoc] = useState("");
  const html = files.filter((el) => {
    return el?.type === "html";
  })[0]?.text;
  const css = files.filter((el) => {
    return el?.type === "css";
  })[0]?.text;
  const js = files.filter((el) => {
    return el?.type === "javascript";
  })[0]?.text;
  useEffect(() => {
    const timeout = setTimeout(() => {
      setSrcDoc(`
        <html>
          <body>${html || ""}</body>
          <style>${css}</style>
          <script>${js}</script>
        </html>
      `);
    }, 250);

    return () => clearTimeout(timeout);
  }, [html, css, js]);

  return (
    <div>
      {files.map((data, index) => (
        <>
          <Editor
            onDelete={() => setFiles(files.filter((item) => item !== data))}
            data={data}
            onChange={({ type, name, text }) =>
              setFiles([
                ...files.slice(0, index),
                { type, name, text },
                ...files.slice(index + 1),
              ])
            }
          />
        </>
      ))}
      <br />
      <div
        style={{
          alignItems: "center",
          textAlign: "center",
          marginBottom: "10px",
        }}
      >
        <div>
          <button
            className="btn btn-primary"
            onClick={() => setFiles([...files, { type: "html" }])}
            key={files}
          >
            Add editor
          </button>

          <iframe
            srcDoc={srcDoc}
            title="output"
            sandbox="allow-scripts"
            frameBorder="0"
            width="95%"
            height="95%"
            style={{
              marginTop: "10px",
              border: "1px solid #F0FFFF",
              boxShadow: "0px 5px 10px 2px rgba(34, 60, 80, 0.2)",
            }}
          />
        </div>
        <div className="input-group mb-3 mt-5 ml-auto mr-auto w-25">
          <div className="input-group-prepend">
            <span className="input-group-text" id="basic-addon1">
              Name of your project
            </span>
          </div>
          <input
            value={title}
            onChange={(e) => setTitle(e.target.value)}
            type="text"
            className="form-control"
            placeholder="Name of project"
            aria-label="Name of project"
            aria-describedby="basic-addon1"
          />
        </div>
        <div className="input-group ml-auto mr-auto w-50">
          <div className="input-group-prepend">
            <span className="input-group-text ">Description</span>
          </div>
          <textarea
            value={description}
            onChange={(e) => setDescription(e.target.value)}
            className="form-control "
            aria-label="With textarea"
            placeholder="Your description"
          ></textarea>
        </div>
        <button
          className="btn btn-success float-right mr-5 mb-5"
          onClick={() => onSave(title, description, files)}
        >
          Save project
        </button>
      </div>
    </div>
  );
};

const ConnectedSnippetHome = connect(null, { onSave: actionSnippetAdd })(
  SnippetHome
);
export default ConnectedSnippetHome;
